@@ -1,4 +1,4 @@
-// Copyright (C) 1995-1999 The Santa Fe Institute.
+// Copyright  1995-1999 The Santa Fe Institute.
 // No warranty implied, see LICENSE for terms.
 
 #import "ObserverSwarm.h"
@@ -12,7 +12,7 @@ main (int argc, const char **argv)
   id observerSwarm;
 
   // Swarm initialization
-  initSwarmApp (argc, argv, "1.4.1", "bug-swarm@santafe.edu");
+  initSwarm (argc, argv);
 
   observerSwarm = [ObserverSwarm create: [Zone create: globalZone]];
   [observerSwarm buildObjects];
